@@ -29,7 +29,6 @@
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <libgames-support/games-clock.h>
 #include <libgames-support/games-conf.h>
-#include <libgames-support/games-gtk-compat.h>
 #include <libgames-support/games-help.h>
 #include <libgames-support/games-scores.h>
 #include <libgames-support/games-scores-dialog.h>
@@ -1117,12 +1116,10 @@ game_score (void)
 {
   gint pos = 0;
   time_t seconds;
-  GamesScoreValue score;
 
   if (!have_been_hinted) {
     seconds = games_clock_get_seconds (GAMES_CLOCK (timer));
-    score.time_double = (gfloat) (seconds / 60) + (gfloat) (seconds % 60) / 100;
-    pos = games_scores_add_score (highscores, score);
+    pos = games_scores_add_time_score (highscores, (gfloat) (seconds / 60) + (gfloat) (seconds % 60) / 100);
   }
 
   if (show_score_dialog (pos, TRUE) == GTK_RESPONSE_REJECT) {
@@ -1466,6 +1463,17 @@ save_state_cb (EggSMClient *client,
   return TRUE;
 }
 
+static gint
+quit_cb (EggSMClient *client,
+         gpointer client_data)
+{
+  quit_game_cb ();
+
+  return FALSE;
+}
+
+#endif /* WITH_SMCLIENT */
+
 static void
 find_first_tile (gint status, gint * xx, gint * yy)
 {
@@ -1588,11 +1596,7 @@ about_cb (GtkAction * action, gpointer data)
   gchar *license = games_get_license (_(APPNAME_LONG));
 
   gtk_show_about_dialog (GTK_WINDOW (window),
-#if GTK_CHECK_VERSION (2, 11, 0)
                          "program-name", _(APPNAME_LONG),
-#else
-                         "name", _(APPNAME_LONG),
-#endif
                          "version", VERSION,
                          "comments",
                          _("GNOME Tetravex is a simple puzzle where "
@@ -1613,17 +1617,6 @@ about_cb (GtkAction * action, gpointer data)
   g_free (license);
 }
 
-static gint
-quit_cb (EggSMClient *client,
-         gpointer client_data)
-{
-  quit_game_cb ();
-
-  return FALSE;
-}
-
-#endif /* WITH_SMCLIENT */
-
 static void
 size_cb (GtkAction * action, gpointer data)
 {
@@ -1798,9 +1791,7 @@ main (int argc, char **argv)
 #endif
 
   context = g_option_context_new (NULL);
-#if GLIB_CHECK_VERSION (2, 12, 0)
   g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
-#endif /* GLIB_CHECK_VERSION (2, 12, 0) */
   g_option_context_add_group (context, gtk_get_option_group (TRUE));
 #ifdef WITH_SMCLIENT
   g_option_context_add_group (context, egg_sm_client_get_option_group ());
